@@ -2,8 +2,8 @@ from bergen.query import DelayedGQL
 
 
 CREATE_REPRESENTATION = DelayedGQL("""
-mutation Representation($sample: ID, $name: String, $tags: [String], $variety: RepresentationVarietyInput){
-  createRepresentation(sample: $sample, name: $name, tags: $tags, variety: $variety){
+mutation Representation($sample: ID, $name: String, $tags: [String], $variety: RepresentationVarietyInput, $creator: ID){
+  createRepresentation(sample: $sample, name: $name, tags: $tags, variety: $variety, creator: $creator){
     name
     id
     variety
